@@ -43,7 +43,7 @@ class Config:
                  reports_csv_path: str,
                  reports_list: list[dict[str, Any]] = [],
                  summary_filepath: str | None = None,
-                 log_filepath: str | None = None,
+                 log_path: str | None = None,
                  report: str = "",
                  path: str = "",
                  threads: int = 0,
@@ -66,7 +66,7 @@ class Config:
         self.reports_csv_path: str = reports_csv_path
         self.reports_list: list[dict[str, Any]] = reports_list
         self.summary_filepath: os.PathLike | None = Path(summary_filepath) if summary_filepath else None
-        self.log_filepath: os.PathLike | None = Path(log_filepath) if log_filepath else None
+        self.log_path: os.PathLike | None = Path(log_path) if log_path else None
         self.report: list[str] = report.split(
             ',') if report else []
         self.path: str = path
@@ -115,7 +115,7 @@ class Config:
 
         logger_main.debug("Parsing input reports - single mode report")
 
-        if len(self.report) != 5:
+        if len(self.report) != 4:
             logger_main.debug(
                 "Parsing input reports - single mode report | optional_params not present")
             self.report.append('')
